The mappings are as follows:

app_name         | normalized_os | product          | canonical_name              | 2019  | 2020
---------------- | ------------- | ---------------- | --------------------------- | ----- | ----
Firefox          | *             | Firefox          | Firefox for Desktop         | true  | true
Fenix            | Android       | Fenix            | Firefox for Android (Fenix) | true  | true
Fennec           | Android       | Fennec           | Firefox for Android (Fennec)| true  | true
Firefox Preview  | Android       | Firefox Preview  | Firefox Preview for Android | true  | true
Fennec           | iOS           | Firefox iOS      | Firefox for iOS             | true  | true
FirefoxForFireTV | Android       | Firefox Fire TV  | Firefox for Fire TV         | false | false
FirefoxConnect   | Android       | Firefox Echo     | Firefox for Echo Show       | true  | true
Zerda            | Android       | Firefox Lite     | Firefox Lite                | true  | true
Zerda_cn         | Android       | Firefox Lite CN  | Firefox Lite (China)        | false | false
Focus            | Android       | Focus Android    | Firefox Focus for Android   | true  | true
Focus            | iOS           | Focus iOS        | Firefox Focus for iOS       | true  | true
Klar             | Android       | Klar Android     | Firefox Klar for Android    | false | false
Klar             | iOS           | Klar iOS         | Firefox Klar for iOS        | false | false
Lockbox          | Android       | Lockwise Android | Lockwise for Android        | true  | true
Lockbox          | iOS           | Lockwise iOS     | Lockwise for iOS            | true  | true
FirefoxReality*  | Android       | Firefox Reality  | Firefox Reality             | false | false
